Connector.scan()
Yield documents from this source.
Usage
Connector.scan()Each call should yield all currently available documents. The sync engine uses content hashes to detect changes.
Yield documents from this source.
Usage
Each call should yield all currently available documents. The sync engine uses content hashes to detect changes.