from talk_box.conversation import Conversation
convo = Conversation()
convo.add_user_message("Hi")
convo.add_assistant_message("Hello!")
convo.get_message_count()2
Return the total number of messages in the conversation.
Usage
Equivalent to len(conversation) but available as an explicit method for discoverability in the API reference.
int