HumanReview.final_content
The content to use going forward.
HumanReview.final_content: str
Returns the revised content if the review was revised, otherwise the original content.
The content to use going forward.
HumanReview.final_content: str
Returns the revised content if the review was revised, otherwise the original content.