MemoryStore.forget()

Remove a memory from the specified tier, or from all tiers.

Usage

MemoryStore.forget(
    key,
    *,
    tier=None,
)

Parameters

key: str

The key to remove.

tier: MemoryTier | None = None
Specific tier to remove from. None removes from all tiers.

Returns

bool
True if the key was found and removed from at least one tier.