TalkBoxConfig.is_cloud_model()
Check whether a model string refers to a cloud provider.
Usage
TalkBoxConfig.is_cloud_model(model_string)Parameters
model_string: str-
A
provider:modelstring (e.g.,"anthropic:claude-sonnet-4-6").
Check whether a model string refers to a cloud provider.
Usage
model_string: strprovider:model string (e.g., "anthropic:claude-sonnet-4-6").