TalkBoxConfig.validate_model()

Validate that a model string is allowed under the current config.

Usage

TalkBoxConfig.validate_model(model_string)

Raises

ValueError
If the model is a cloud model and allow_cloud is False.