KnowledgeGraph.clear_layer()
Delete all nodes and edges belonging to a specific layer.
Usage
KnowledgeGraph.clear_layer(layer)Edges are deleted first (those whose source or target is in the layer), then the nodes themselves.
Parameters
layer: GraphLayer- The graph layer to clear.
Returns
int- Number of nodes removed.