LongTermMemory.search()
Search long-term memory by tags and/or key prefix.
Usage
LongTermMemory.search(
*,
tags=None,
prefix=None,
)Parameters
tags: list[str] | None = None-
Filter to entries that have all of these tags.
prefix: str | None = None- Filter to entries whose key starts with this prefix.
Returns
list[MemoryEntry]- Matching entries, sorted by timestamp.