get_global_registry()
Return the process-wide ToolRegistry singleton.
Usage
get_global_registry()All @tool-decorated functions are registered here by default. Use this function when you need to inspect, iterate, or pass the registry to other components such as ToolEnabledConversation or ChatBot.
Returns
ToolRegistry- The global registry instance.
Examples
import talk_box as tb
registry = tb.get_global_registry()
all_tools = registry.get_all_tools()